@@ -45,6 +45,7 @@
 #'       \item{\code{soilFunctions [= "VG"]}: Soil water retention curve and conductivity functions, either 'SX' (for Saxton) or 'VG' (for Van Genuchten). 
 #'                  If \code{transpirationMode} is 'Sperry' or 'Sureau' then soilFunctions is forced to \code{'VG'}.
 #'                  Only simulations with 'Granier' are allowed to use Saxton functions.}
+#'       \item{\code{truncateRootDistribution [= FALSE]}: Boolean flag to indicate that fine root distribution is to be truncated (i.e. Z100 is estimated from Z95 when not provided).}
 #'       \item{\code{VG_PTF}: String indicating the pedotransfer functions for van Genuchten parameters (either 'Toth' or 'Carsel').}
 #'       \item{\code{ndailysteps [= 24]}: Number of steps into which each day is divided for determination of soil water balance, stomatal conductance, transpiration and photosynthesis (24 equals 1-hour intervals).}
 #'       \item{\code{max_nsubsteps_soil [= 300]}: Maximum number of substeps for soil water balance solving.}
@@ -118,7 +119,6 @@
 #'     \itemize{
 #'       \item{\code{plantCapacitance [= TRUE]}: Whether the effect of (symplasmic) plant water compartments is considered in simulations.}
 #'       \item{\code{cavitationFlux [= TRUE]}: Whether the effect of water flux generated by cavitation of apoplasmic tissues is considered in simulations.}
-#'       \item{\code{soilDisconnection [= FALSE]}: Whether the ability of the plants to physically disconnect their root system from the soil is considered in simulations.}
 #'       \item{\code{leafCuticularTranspiration [= TRUE]}: Whether the effect of leaf cuticular transpiration is considered in simulations.}
 #'       \item{\code{stemCuticularTranspiration [= FALSE]}: Whether the effect of stem cuticular transpiration is considered in simulations.}
 #'       \item{\code{C_SApoInit [= 2.0e-5]}: Maximum capacitance of the stem apoplasm (mmol·m-2).}
@@ -153,8 +153,8 @@
 #'       \item{\code{mortalityRWCThreshold [= 0.4]}: Threshold of stem relative water content resulting in increased mortality rate/probability whenever levels are below.}
 #'       \item{\code{recrTreeDBH [= 1]}: Default DBH (cm) for recruited trees  (when species parameter \code{RecrTreeDBH} is missing).}
 #'       \item{\code{recrTreeDensity [= 3000]}: Default density (ind·ha-1) for recruited trees  (when species parameter \code{RecrTreeDensity} is missing).}
-#'       \item{\code{ingrowthTreeDBH [= 7.5]}: Default DBH (cm) for ingrowth trees  (when species parameter \code{RecrTreeDBH} is missing).}
-#'       \item{\code{ingrowthTreeDensity [= 127]}: Default density (ind·ha-1) for ingrowth trees  (when species parameter \code{RecrTreeDensity} is missing).}
+#'       \item{\code{ingrowthTreeDBH [= 7.5]}: Default DBH (cm) for ingrowth trees  (when species parameter \code{IngrowthTreeDBH} is missing).}
+#'       \item{\code{ingrowthTreeDensity [= 127]}: Default density (ind·ha-1) for ingrowth trees  (when species parameter \code{IngrowthTreeDensity} is missing).}
 #'    }
 #'   \bold{Forest dynamics} (function \code{\link{fordyn}}):
 #'    \itemize{
@@ -208,7 +208,6 @@ defaultControl<-function(transpirationMode = "Granier",
     soilPoolResults = FALSE,
     snowResults = TRUE,
     plantResults = TRUE,
-    plantWaterBalanceResults = TRUE,
     labileCarbonBalanceResults = TRUE,
     plantStructureResults = TRUE,
     growthMortalityResults = TRUE,
@@ -222,6 +221,7 @@ defaultControl<-function(transpirationMode = "Granier",
     transpirationMode = transpirationMode,
     soilDomains = soilDomains,
     rhizosphereOverlap = rhizosphereOverlap,
+    truncateRootDistribution = FALSE,
     fullRhizosphereOverlapConductivity = 0.01,
     soilFunctions = "VG",
     VG_PTF = "Toth",
@@ -271,7 +271,6 @@ defaultControl<-function(transpirationMode = "Granier",
     stomatalSubmodel = "Baldocchi",
     plantCapacitance = TRUE,
     cavitationFlux = TRUE,
-    soilDisconnection = FALSE,
     leafCuticularTranspiration = TRUE,
     stemCuticularTranspiration = FALSE,
     C_SApoInit = 2.0e-05,
