@@ -1421,6 +1421,21 @@ double standLAI(List x, DataFrame SpParams, double gdd = NA_REAL,
   return(tl);
 }
 
+void updateLAIdistributionVectors(NumericMatrix LAIdist, NumericVector z, NumericVector LAI, NumericVector H, NumericVector CR) {
+  int ncanlayers = LAIdist.nrow();
+  int numCohorts = LAIdist.ncol();
+  for(int ci=0;ci<numCohorts;ci++) {
+    double cbh = H[ci]*(1.0-CR[ci]);
+    for(int hi=0;hi<ncanlayers;hi++) {
+      if(z[hi]<= H[ci]) {
+        LAIdist(hi,ci) = LAI[ci]*leafAreaProportion(z[hi],z[hi+1], cbh,H[ci]);
+      } else {
+        LAIdist(hi,ci) = 0.0;
+      }
+    }
+  }
+}
+
 
 // [[Rcpp::export(".LAIdistributionVectors")]]
 NumericMatrix LAIdistributionVectors(NumericVector z, NumericVector LAI, NumericVector H, NumericVector CR) {
@@ -1428,18 +1443,11 @@ NumericMatrix LAIdistributionVectors(NumericVector z, NumericVector LAI, Numeric
   int ncoh = LAI.size();
   // double h1, h2;
   NumericMatrix LAIdist(nh-1, ncoh);
-  for(int ci=0;ci<ncoh;ci++) {
-    double cbh = H[ci]*(1.0-CR[ci]);
-    // double laih = LAI[ci]/(H[ci]-cbh);
-    for(int hi=0;hi<(nh-1);hi++) {
-      // h1 = std::max(z[hi],cbh);
-      // h2 = std::min(z[hi+1],H[ci]);
-      LAIdist(hi,ci) = LAI[ci]*leafAreaProportion(z[hi],z[hi+1], cbh,H[ci]);
-      // LAIdist(hi,ci) =laih*std::max(0.0, h2 - h1);
-    }
-  }
+  LAIdist.fill(0.0);
+  updateLAIdistributionVectors(LAIdist, z, LAI, H, CR);
   return(LAIdist);
 }
+
 // [[Rcpp::export(".LAIdistribution")]]
 NumericMatrix LAIdistribution(NumericVector z, List x, DataFrame SpParams, double gdd = NA_REAL, 
                               bool bounded = true) {
