@@ -8,7 +8,7 @@ using namespace Rcpp;
 NumericVector layerThermalConductivity(NumericVector sand, NumericVector clay, 
                                        NumericVector W, NumericVector Theta_SAT, NumericVector Theta_FC,
                                        NumericVector Temp);
-NumericVector temperatureChange(NumericVector widths, NumericVector Temp,
-                                NumericVector sand, NumericVector clay, 
-                                NumericVector W, NumericVector Theta_SAT, NumericVector Theta_FC,
-                                double Gdown, double tstep);
+NumericVector temperatureChange_inner(List SEBcommunication, NumericVector widths, NumericVector Temp,
+                                      NumericVector sand, NumericVector clay, 
+                                      NumericVector W, NumericVector Theta_SAT, NumericVector Theta_FC,
+                                      double Gdown, double tstep);
