@@ -128,6 +128,14 @@ test_that("spwb can be run using partial rhizosphere overlap",{
                        latitude = 41.82592, elevation = 100), "spwb")
 })
 
+test_that("spwb can be run with fire hazard results",{
+  control_fh <- control_granier
+  control_fh$fireHazardResults <- TRUE
+  expect_s3_class(spwb(spwbInput(exampleforest, examplesoil, SpParamsMED, control_fh), 
+                       examplemeteo[1:2,],
+                       latitude = 41.82592, elevation = 100), "spwb")
+})
+
 test_that("spwb can be run with less output",{
   control_less <- control_granier
   control_less$standResults <- FALSE
@@ -200,3 +208,40 @@ test_that("spwb_day gives same result with inner and direct calls with general c
   expect_equal(medfate::copy_model_output(ic, x3i, "spwb"), s_dir)
 
 })
+
+test_that("spwb_day can be run with truncated root distribution",{
+  exampleforest$shrubData$Z50 <- 100
+  exampleforest$shrubData$Z95 <- 200
+  control_granier$truncateRootDistribution<- TRUE
+  x1 <- spwbInput(exampleforest, examplesoil, SpParamsMED, control_granier)
+  expect_s3_class(spwb_day(x1, date, meteovec,
+                           latitude = 41.82592, elevation = 100, slope=0, aspect=0), "spwb_day")
+  control_sperry$truncateRootDistribution<- TRUE
+  x2 <- spwbInput(exampleforest, examplesoil, SpParamsMED, control_sperry)
+  expect_s3_class(spwb_day(x2, date, meteovec,
+                           latitude = 41.82592, elevation = 100, slope=0, aspect=0), "spwb_day")
+  control_sureau$truncateRootDistribution<- TRUE
+  x3 <- spwbInput(exampleforest, examplesoil, SpParamsMED, control_sureau)
+  expect_s3_class(spwb_day(x3, date, meteovec,
+                           latitude = 41.82592, elevation = 100, slope=0, aspect=0), "spwb_day")
+})
+
+test_that("spwb_day can be run with truncated root distribution and rhizosphere overlap",{
+  exampleforest$shrubData$Z50 <- 100
+  exampleforest$shrubData$Z95 <- 200
+  control_granier$truncateRootDistribution<- TRUE
+  control_granier$rhizosphereOverlap <- "partial"
+  x1 <- spwbInput(exampleforest, examplesoil, SpParamsMED, control_granier)
+  expect_s3_class(spwb_day(x1, date, meteovec,
+                           latitude = 41.82592, elevation = 100, slope=0, aspect=0), "spwb_day")
+  control_sperry$truncateRootDistribution<- TRUE
+  control_sperry$rhizosphereOverlap <- "partial"
+  x2 <- spwbInput(exampleforest, examplesoil, SpParamsMED, control_sperry)
+  expect_s3_class(spwb_day(x2, date, meteovec,
+                           latitude = 41.82592, elevation = 100, slope=0, aspect=0), "spwb_day")
+  control_sureau$truncateRootDistribution<- TRUE
+  control_sureau$rhizosphereOverlap <- "partial"
+  x3 <- spwbInput(exampleforest, examplesoil, SpParamsMED, control_sureau)
+  expect_s3_class(spwb_day(x3, date, meteovec,
+                           latitude = 41.82592, elevation = 100, slope=0, aspect=0), "spwb_day")
+})
